<?php

namespace App\Http\Controllers\API;

use App\Http\Requests\API\CreateChampionshipAPIRequest;
use App\Http\Requests\API\UpdateChampionshipAPIRequest;
use App\Http\Resources\ChampionshipLevelExamResource;
use App\Http\Resources\ChampionshipLevelResource;
use App\Http\Resources\ChampionshipSubscriberResource;
use App\Http\Resources\CompetitionResource;
use App\Http\Resources\MyChampionshipResource;
use App\Http\Resources\QuestionResource;
use App\Http\Resources\TypeLevelResource;
use App\Models\AgeCategory;
use App\Models\Championship;
use App\Models\ChampionshipLevel;
use App\Models\ChampionshipSubscriber;
use App\Models\CompetitionSubscriber;
use App\Models\Models\SubscriberChampionshipQuestionAnswer;
use App\Models\Models\SubscriberCompetitionQuestionAnswer;
use App\Models\Question;
use App\Repositories\ChampionshipRepository;
use Illuminate\Support\Facades\App;
use PDF;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use App\Http\Controllers\AppBaseController;
use App\Http\Resources\ChampionshipResource;
use App\Http\Resources\ChampionshipLevelDetailsResource;
use App\Http\Resources\ChampionshipWinnersSubscriberResource;
use Carbon\Carbon;
use Intervention\Image\Drivers\Gd\Driver;
use Intervention\Image\ImageManager;
use Response;
use Validator;



/**
 * Class ChampionshipController
 * @package App\Http\Controllers\API
 */

class ChampionshipAPIController extends AppBaseController
{
    /** @var  ChampionshipRepository */
    private $championshipRepository;

    public function __construct(ChampionshipRepository $championshipRepo)
    {
        $this->championshipRepository = $championshipRepo;
    }

    /**
     * Display a listing of the Championship.
     * GET|HEAD /championships
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function index(Request $request)
    {
        $championships = $this->championshipRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        );

        return $this->sendResponse(
            ChampionshipResource::collection($championships),
            __('messages.retrieved', ['model' => __('models/championships.plural')])
        );
    }

    public function update_championship_levels($id, Request $request): JsonResponse
    {
        $championship = $this->championshipRepository->find($id);
        if ($request->levels) {
            $championship->levels()->sync($request->levels);
            $championship->save();
        }

        return $this->sendResponse(
            ChampionshipLevelResource::collection($championship->levels),
            __('messages.retrieved', ['model' => __('models/typeLevels.plural')])
        );
    }

    public function add_level_exam(): JsonResponse
    {
        $championship_level = ChampionshipLevel::where('championship_id', \request('championship_id'))->where('type_level_id', \request('type_level_id'))->first();
        //$championship_level->questions_count = \request('questions_count');
        $championship_level->question_speed = \request('question_speed');
        $championship_level->questions_count_2num = \request('questions_count_2num');
        $championship_level->questions_count_3num = \request('questions_count_3num');
        $championship_level->questions_count_4num = \request('questions_count_4num');
        $championship_level->questions_count_5num = \request('questions_count_5num');
        $championship_level->questions_count_6num = \request('questions_count_6num');
        $championship_level->questions_count_7num = \request('questions_count_7num');
        $championship_level->questions_count_8num = \request('questions_count_8num');
        $championship_level->questions_count_9num = \request('questions_count_9num');
        $championship_level->questions_count_10num = \request('questions_count_10num');
        $championship_level->save();

        $all_questions = $this->championshipRepository->get_questions($championship_level);//

        if(is_countable($all_questions) == false){
            return  $all_questions ;
        }

        $championship_level->questions()->sync($all_questions->pluck('id')->toArray());

        return $this->sendResponse(
            new ChampionshipLevelExamResource($championship_level),
            __('messages.updated', ['model' => __('models/typeLevels.singular')])
        );
    }

    public function add_levels_exams(): JsonResponse
    {
        foreach (\request('levels') as $level){
            $championship_level = ChampionshipLevel::where('championship_id', \request('championship_id'))->where('type_level_id', $level['level_id'])->first();
            $championship_level->questions_count = isset($level['questions_count']) ? $level['questions_count']:null;
            $championship_level->question_speed =  isset($level['question_speed'] )?$level['question_speed']:null;
            $championship_level->questions_count_2num =  isset($level['questions_count_2num']) ? $level['questions_count_2num']:null;
            $championship_level->questions_count_3num =  isset($level['questions_count_3num']) ? $level['questions_count_3num']:null;
            $championship_level->questions_count_4num =  isset($level['questions_count_4num']) ? $level['questions_count_4num']:null;
            $championship_level->questions_count_5num =  isset($level['questions_count_5num']) ? $level['questions_count_5num']:null;
            $championship_level->questions_count_6num =  isset($level['questions_count_6num'] )? $level['questions_count_6num']:null;
            $championship_level->questions_count_7num =  isset($level['questions_count_7num']) ? $level['questions_count_7num']:null;
            $championship_level->questions_count_8num =  isset($level['questions_count_8num']) ? $level['questions_count_8num']:null;
            $championship_level->questions_count_9num =   isset($level['questions_count_9num'] )? $level['questions_count_9num']:null;
            $championship_level->questions_count_10num =  isset($level['questions_count_10num']) ? $level['questions_count_10num']:null;
            $championship_level->save();

            $all_questions = $this->championshipRepository->get_questions($championship_level);//

            if (count($all_questions) == 0) {
                return $this->sendError('No Questions Available for this setting');
            }

            $championship_level->questions()->sync($all_questions->pluck('id')->toArray());
        }


        $championship = $this->championshipRepository->find(\request('championship_id'));

        return $this->sendResponse(
            ChampionshipLevelExamResource::collection($championship->championship_levels),
            __('messages.updated', ['model' => __('models/typeLevels.singular')])
        );
    }

    public function get_questions($championship_level)
    {
        return Question::where('active', 1)
            ->where('type_level_id', $championship_level->type_level_id)->where('numbers_count', $championship_level->numbers_count)->take($championship_level->questions_count)->get();
    }

    public function my_champions(Request $request)
    {
        if ($request->user()?->role == 'student') {
            $championships = Championship::whereHas('subscribers', fn($query) => $query->where('user_id', auth('sanctum')->id()))->get();

            return $this->sendResponse(
                ChampionshipResource::collection($championships),
                __('messages.retrieved', ['model' => __('models/championships.plural')])
            );
        }
    }


    public function certificates(Request $request): \Illuminate\Http\JsonResponse
    {
        $data = [];
        $last_championship = Championship::where('finish', 1)->orderBy('start_at', 'desc')->first();
        if ($last_championship <> null) {
            $data['last_championship_result'] = ChampionshipWinnersSubscriberResource::collection($last_championship->winners_subscribers()->take(3)->get());
        }
        if ($request->user()?->role == 'student') {
            $championships = Championship::where('finish', 1)->whereHas('winners_subscribers', fn($query) => $query->where('user_id', auth('sanctum')->id()))->get();
            if ($championships <> null) {
                $data['my_champions_results'] = MyChampionshipResource::collection($championships);
            }
        }

        return $this->sendResponse(
            $data,
            __('messages.retrieved', ['model' => __('models/championships.plural')])
        );
    }

    public function certificate($id): \Illuminate\Http\JsonResponse
    {
        $championship = $this->championshipRepository->find($id);

        if (empty($championship)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/championships.singular')])
            );
        }

        return $this->sendResponse(
            new MyChampionshipResource($championship),
            __('messages.retrieved', ['model' => __('models/championships.singular')])
        );
    }

    public function download()
    {

        $manager = new ImageManager(new Driver());

// read image from file system
$image = $manager->read(public_path('certificates_blade/Certificate-Ar.png'));


$image->text('Ahmed Mohamed Ahmed', 170, 145, function($font) {
    $font->file(public_path('fonts/SansitaSwashed-Regular.TTF'));
    $font->size(18);
    $font->color('#ff7300');
    $font->align('center');
    $font->valign('bottom');
    $font->angle(0);
});


$image->text('Challenge of champioships', 170, 68, function($font) {
    $font->file(public_path('fonts/Aclonica-Regular.TTF'));
    $font->size(10);
    $font->color('#607685');
    $font->align('center');
    $font->valign('bottom');
    $font->angle(0);
});


$image->text('12/07/2025', 265, 230, function($font) {
    $font->file(public_path('fonts/Aclonica-Regular.TTF'));
    $font->size(10);
    $font->color('#000000');
    $font->align('center');
    $font->valign('bottom');
    $font->angle(0);
});


$image->text('05 jan 2025', 90, 165, function($font) {
    $font->file(public_path('fonts/Aclonica-Regular.TTF'));
    $font->size(9);
    $font->color('#203f54');
    $font->align('center');
    $font->valign('bottom');
    $font->angle(0);
});

// insert watermark
//$image->place('images/watermark.png');

// save modified image in new format
        $image->save(public_path('new.png'));




    }

    /**
     * Store a newly created Championship in storage.
     * POST /championships
     *
     * @param CreateChampionshipAPIRequest $request
     *
     * @return \Illuminate\Http\JsonResponse
     */
    public function store(CreateChampionshipAPIRequest $request)
    {
        $input = $request->all();

        if(isset($request->start_at)){
            $input['expired_at'] = Carbon::parse($request->start_at)->addMinutes($request->training_period)->timezone('Africa/Cairo');
        }

        $championship = $this->championshipRepository->create($input);

        if ($request->levels) {
            $championship->levels()->sync($request->levels);
        }

        return $this->sendResponse(
            new ChampionshipResource($championship),
            __('messages.saved', ['model' => __('models/championships.singular')])
        );
    }

    /**
     * Display the specified Championship.
     * GET|HEAD /championships/{id}
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        /** @var Championship $championship */
        $championship = $this->championshipRepository->find($id);

        if (empty($championship)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/championships.singular')])
            );
        }

        return $this->sendResponse(
            new ChampionshipResource($championship),
            __('messages.retrieved', ['model' => __('models/championships.singular')])
        );
    }

    /**
     * Update the specified Championship in storage.
     * PUT/PATCH /championships/{id}
     *
     * @param int $id
     * @param UpdateChampionshipAPIRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateChampionshipAPIRequest $request)
    {
        $input = $request->all();

        /** @var Championship $championship */
        $championship = $this->championshipRepository->find($id);

        if (empty($championship)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/championships.singular')])
            );
        }

        $championship = $this->championshipRepository->update($input, $id);

        if ($request->levels) {
            $championship->levels()->sync($request->levels);
        }

        return $this->sendResponse(
            new ChampionshipResource($championship),
            __('messages.updated', ['model' => __('models/championships.singular')])
        );
    }

    /**
     * Remove the specified Championship from storage.
     * DELETE /championships/{id}
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        /** @var Championship $championship */
        $championship = $this->championshipRepository->find($id);

        if (empty($championship)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/championships.singular')])
            );
        }

        $championship->delete();

        return $this->sendResponse(
            $id,
            __('messages.deleted', ['model' => __('models/championships.singular')])
        );
    }

    public function activateToggle($id): \Illuminate\Http\JsonResponse
    {
        $championship = $this->championshipRepository->find($id);
        $championship->active = !$championship->active;
        $championship->save();

        return $this->sendResponse(
            new ChampionshipResource($championship),
            __('messages.updated', ['model' => __('models/championships.singular')])
        );
    }


    public function answer_championship_questions()
    {
        $validator = Validator::make(\request()->all(), [
            'questions' => 'required|array',
        ]);
        if ($validator->fails()) {
            return $this->sendError($validator->errors()->first());
        }

        $championship = $this->championshipRepository->find(\request('championship_id'));

        if (empty($championship)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/championships.singular')])
            );
        }

        foreach (\request('questions') as $i => $question_id) {
            $answer_question = new SubscriberChampionshipQuestionAnswer();
            $answer_question->championship_subscriber_id = ChampionshipSubscriber::where('championship_id', \request('championship_id'))->where('user_id', auth('sanctum')->id())->first()->id;
            $answer_question->championship_id = \request('championship_id');
            $answer_question->question_id = $question_id;
            $answer_question->user_id = auth('sanctum')->id();
            $answer_question->is_correct = \request('is_correct')[$i];
            $answer_question->wrong_answer = \request('wrong_answer')[$i];
            $answer_question->save();
        }


        return $this->sendResponse(
            new ChampionshipResource($championship),
            __('messages.updated', ['model' => __('models/championships.singular')])
        );
    }

    public function start_championship($id)
    {
        /** @var Championship $championship */
        $championship = $this->championshipRepository->find($id);

        if (empty($championship)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/championships.singular')])
            );
        }

        $championshipSubscriber = ChampionshipSubscriber::where('championship_id', $id)->where('user_id', auth('sanctum')->id())->where('active', 1)->first();

        if (empty($championshipSubscriber)) {
            return $this->sendError(
                'You are not allowed to start this championship'
            );
        }


        $championship_level = ChampionshipLevel::where('championship_id', $id)->where('type_level_id', $championshipSubscriber->type_level_id)->first();


        if (empty($championship_level)) {
            return $this->sendError(
                'Championship level not found'
            );
        }


        return $this->sendResponse(
            new ChampionshipLevelDetailsResource($championship_level),
            __('messages.updated', ['model' => __('models/typeLevels.singular')])
        );
    }

    public function finish_championship($id)
    {
        /** @var Championship $championship */
        $championship = $this->championshipRepository->find($id);
        $championship->finish = 1;
        $championship->save();

        if (empty($championship)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/championships.singular')])
            );
        }

        foreach (AgeCategory::get() as $ageCategory) {
            foreach (ChampionshipSubscriber::where('championship_id', $id)->where('age_category_id', $ageCategory->id)->where('active', 1)->orderByDesc('supposed_solved')->limit(3)->get() as $order => $subscriber) {
                $subscriber->order = $order + 1;
                $subscriber->certificate_ar = CertificateAr($subscriber->user->name, $championship->title, $championship->start_at);
                $subscriber->certificate_en = CertificateEng($subscriber->user->name, $championship->title, $championship->start_at);
                $subscriber->save();
            }
        }

        return $this->sendResponse(
            new ChampionshipResource($championship),
            __('messages.updated', ['model' => __('models/championships.singular')])
        );


    }

}
