<?php

namespace App\Http\Controllers\API;

use App\Http\Requests\API\CreateCompetitionSubscriberAPIRequest;
use App\Http\Requests\API\UpdateCompetitionSubscriberAPIRequest;
use App\Models\Competition;
use App\Models\CompetitionSubscriber;
use App\Models\Setting;
use App\Repositories\CompetitionSubscriberRepository;
use Illuminate\Http\Request;
use App\Http\Controllers\AppBaseController;
use App\Http\Resources\CompetitionSubscriberResource;
use Response;

/**
 * Class CompetitionSubscriberController
 * @package App\Http\Controllers\API
 */

class CompetitionSubscriberAPIController extends AppBaseController
{
    /** @var  CompetitionSubscriberRepository */
    private $competitionSubscriberRepository;

    public function __construct(CompetitionSubscriberRepository $competitionSubscriberRepo)
    {
        $this->competitionSubscriberRepository = $competitionSubscriberRepo;
    }

    /**
     * Display a listing of the CompetitionSubscriber.
     * GET|HEAD /competitionSubscribers
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function index(Request $request)
    {
        $competitionSubscribers = $this->competitionSubscriberRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        )->where('competition_id',$request->competition_id);

        return $this->sendResponse(
            CompetitionSubscriberResource::collection($competitionSubscribers),
            __('messages.retrieved', ['model' => __('models/competitionSubscribers.plural')])
        );
    }


    public function add_competition_result_to_subscriber(UpdateCompetitionSubscriberAPIRequest $request): \Illuminate\Http\JsonResponse
    {
        $input = $request->all();

        /** @var CompetitionSubscriber $competitionSubscriber */
        $competitionSubscriber = CompetitionSubscriber::where('competition_id',$request->competition_id)->where('user_id',auth('sanctum')->id())->first();

        if (empty($competitionSubscriber)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/competitionSubscribers.singular')])
            );
        }

        if ($request->correct_answers_count){
            $input['student_points'] = $request->correct_answers_count * Setting::first()->competition_points ;
        }

        if ($request->answering_period && $request->correct_answers_count){
            $competition = Competition::find($request->competition_id);
            $input['supposed_solved'] = exam_equation($competition->training_period * 60,$request->answering_period * 60,$request->correct_answers_count) ;
        }

        $competitionSubscriber = $this->competitionSubscriberRepository->update($input, $competitionSubscriber->id);

        return $this->sendResponse(
            new CompetitionSubscriberResource($competitionSubscriber),
            __('messages.updated', ['model' => __('models/competitionSubscribers.singular')])
        );
    }

    public function collectStudentPoints(Request $request): \Illuminate\Http\JsonResponse
    {
        $competitionSubscriber = CompetitionSubscriber::where('competition_id',$request->competition_id)->where('user_id',auth('sanctum')->id())->first();
        if ( $competitionSubscriber->student_points_is_collected == 0){
            $competitionSubscriber->student_points_is_collected = 1;
            $competitionSubscriber->save();

            $user = auth('sanctum')->user();
            $user->student_points = $user->student_points + $competitionSubscriber->student_points;
            $user->save();
        }
        return $this->sendResponse(
            new CompetitionSubscriberResource($competitionSubscriber),
            __('messages.updated', ['model' => __('models/competitionSubscribers.singular')])
        );
    }

    /**
     * Remove the specified CompetitionSubscriber from storage.
     * DELETE /competitionSubscribers/{id}
     *
     * @param int $id
     *
     * @return \Illuminate\Http\JsonResponse
     * @throws \Exception
     *
     */
    public function destroy($id)
    {
        /** @var CompetitionSubscriber $competitionSubscriber */
        $competitionSubscriber = $this->competitionSubscriberRepository->find($id);

        if (empty($competitionSubscriber)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/competitionSubscribers.singular')])
            );
        }

        $competitionSubscriber->delete();

        return $this->sendResponse(
            $id,
            __('messages.deleted', ['model' => __('models/competitionSubscribers.singular')])
        );
    }

    public function activateToggle($id): \Illuminate\Http\JsonResponse
    {
        $competitionSubscriber = CompetitionSubscriber::where('competition_id',$id)->where('user_id',auth('sanctum')->id())->first();
        $competitionSubscriber->active = !$competitionSubscriber->active;
        $competitionSubscriber->save();

        return $this->sendResponse(
            new CompetitionSubscriberResource($competitionSubscriber),
            __('messages.updated', ['model' => __('models/competitionSubscribers.singular')])
        );
    }
}
