<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\AppBaseController;
use App\Http\Resources\admin\StudentResource;
use App\Http\Resources\admin\TrainerResource;
use App\Http\Resources\AgeCategoryResource;
use App\Http\Resources\UserResource;
use App\Models\Championship;
use App\Models\Question;
use App\Models\User;
use App\Models\Permission;
use App\Models\AgeCategory;
use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Http\Resources\ChampionshipWinnersSubscriberResource;

class DashController extends AppBaseController
{
    public function index(Request $request): \Illuminate\Http\JsonResponse
    {
        $data = [];
        $data['students_count'] = User::where('role', 'student')->count();
        $data['online_students_count'] = User::where('role', 'student')->where('online', 1)->count();
        $data['subscription_students_count'] = User::where('role', 'student')
            ->whereHas('subscription', fn($query) => $query->where('active', 1))->count();

        $data['trainers_count'] = User::where('role', 'trainer')->count();
        $data['special_trainers_count'] = User::where('role', 'trainer')->where('special_trainer', 1)->count();
        $data['subscription_trainers_count'] = User::where('role', 'trainer')
            ->whereHas('subscription', fn($query) => $query->where('active', 1))->count();

        $data['championships_count'] = Championship::count();
        $data['questions_count'] = Question::count();

        $data['most_trainings_students_count'] = User::where('role', 'student')
            ->whereHas('trainings', fn($query) => $query->where('finish', 1))->count();

        $data['last_championship_subscribers'] = Championship::where('finish', 1)->orderBy('start_at', 'desc')->first() <> null ? Championship::where('finish', 1)->orderBy('start_at', 'desc')->first()->subscribers()->count() : null;
        $data['last_championship_winners_subscribers'] = Championship::where('finish', 1)->orderBy('start_at', 'desc')->first() <> null ? Championship::where('finish', 1)->orderBy('start_at', 'desc')->first()->winners_subscribers()->count() : null;

        $data['students_attendence_chart'] = User::where('role', 'student')->whereYear('created_at', Carbon::now()->year)->get()->groupBy(function ($d) {
            return Carbon::parse($d->created_at)->format('M');
        })->map(function ($item) {
            return count($item);
        });
        $data['trainers_attendence_chart'] = User::where('role', 'trainer')->whereYear('created_at', Carbon::now()->year)->get()->groupBy(function ($d) {
            return Carbon::parse($d->created_at)->format('M');
        })->map(function ($item) {
            return count($item);
        });
        $data['championships_attendence_chart'] = Championship::whereYear('created_at', Carbon::now()->year)->get()->groupBy(function ($d) {
            return Carbon::parse($d->created_at)->format('M');
        })->map(function ($item) {
            return count($item);
        });

        return $this->sendResponseWithoutPagination(
            $data,
            __('messages.retrieved', ['model' => 'Dash'])
        );
    }

    public function last_championship_winners_subscribers(): \Illuminate\Http\JsonResponse
    {
        $last_championship = Championship::where('finish', 1)->orderBy('start_at', 'desc')->first();
        $data = [];

        foreach (AgeCategory::get() as $ageCategory) {
            $data['last_championship_winners_subscribers'][$ageCategory->slug] = $last_championship? ChampionshipWinnersSubscriberResource::collection($last_championship->winners_subscribers()->where('age_category_id', $ageCategory->id)->get()):null ;
        }

        return $this->sendResponseWithoutPagination($data, __('messages.retrieved', ['model' => 'Dash']));
    }

    public function last_login_users(): \Illuminate\Http\JsonResponse
    {
        $last_login_users = User::whereNotNull('last_login_at')->orderBy('last_login_at', 'desc');


        if (request('rows')){
            $last_login_users = $last_login_users->paginate(request('rows'));
        }
        else{
            $last_login_users = $last_login_users->get();
        }


        return $this->sendResponse(UserResource::collection($last_login_users), __('messages.retrieved', ['model' => 'Users']));
    }

    public function most_students(): \Illuminate\Http\JsonResponse
    {
        $most_students = User::whereNotNull('student_points')->orderBy('student_points', 'desc');

        if (request('rows')){
            $most_students = $most_students->paginate(request('rows'));
        }
        else{
            $most_students = $most_students->get();
        }

        return $this->sendResponse(StudentResource::collection($most_students), __('messages.retrieved', ['model' => 'Users']));
    }

    public function subscription_students(): \Illuminate\Http\JsonResponse
    {
        $subscription_students = User::where('role', 'student')
        ->whereHas('subscription', fn($query) => $query->where('active', 1));


        if (request('rows')){
            $subscription_students = $subscription_students->paginate(request('rows'));
        }
        else{
            $subscription_students = $subscription_students->get();
        }

        return $this->sendResponse(StudentResource::collection($subscription_students), __('messages.retrieved', ['model' => 'Users']));
    }

    public function most_trainings_students(): \Illuminate\Http\JsonResponse
    {
        $most_trainings_students =User::where('role', 'student')
        ->whereHas('trainings', fn($query) => $query->where('finish', 1));

        if (request('rows')){
            $most_trainings_students = $most_trainings_students->paginate(request('rows'));
        }
        else{
            $most_trainings_students = $most_trainings_students->get();
        }

        return $this->sendResponse(StudentResource::collection($most_trainings_students), __('messages.retrieved', ['model' => 'Users']));
    }


    public function subscription_trainers(): \Illuminate\Http\JsonResponse
    {
        $subscription_trainers = User::where('role', 'trainer')
        ->whereHas('subscription', fn($query) => $query->where('active', 1));

        if (request('rows')){
            $subscription_trainers = $subscription_trainers->paginate(request('rows'));
        }
        else{
            $subscription_trainers = $subscription_trainers->get();
        }

        return $this->sendResponse(TrainerResource::collection($subscription_trainers), __('messages.retrieved', ['model' => 'Users']));
    }



    public function get_all_permissions(Request $request): \Illuminate\Http\JsonResponse
    {
        return $this->sendResponseWithoutPagination(
            Permission::get(),
            __('messages.retrieved', ['model' => 'Permission'])
        );
    }


    public function attendence_chart(Request $request): \Illuminate\Http\JsonResponse
    {
        $data = [];
        $data['students'] = User::where('role', 'student')->whereYear('created_at', Carbon::now()->year)->get()->groupBy(function ($d) {
            return Carbon::parse($d->created_at)->format('M');
        })->map(function ($item) {
            return count($item);
        });
        $data['trainers'] = User::where('role', 'trainer')->whereYear('created_at', Carbon::now()->year)->get()->groupBy(function ($d) {
            return Carbon::parse($d->created_at)->format('M');
        })->map(function ($item) {
            return count($item);
        });
        $data['championships'] = Championship::whereYear('created_at', Carbon::now()->year)->get()->groupBy(function ($d) {
            return Carbon::parse($d->created_at)->format('M');
        })->map(function ($item) {
            return count($item);
        });
        return $this->sendResponseWithoutPagination($data, __('messages.retrieved', ['model' => 'Dash']));
    }




}
