<?php

namespace App\Http\Controllers\API;

use App\Http\Requests\API\CreateTrainerReviewAPIRequest;
use App\Http\Requests\API\UpdateTrainerReviewAPIRequest;
use App\Models\TrainerReview;
use App\Repositories\TrainerReviewRepository;
use Illuminate\Http\Request;
use App\Http\Controllers\AppBaseController;
use App\Http\Resources\TrainerReviewResource;
use Response;

/**
 * Class TrainerReviewController
 * @package App\Http\Controllers\API
 */

class TrainerReviewAPIController extends AppBaseController
{
    /** @var  TrainerReviewRepository */
    private $trainerReviewRepository;

    public function __construct(TrainerReviewRepository $trainerReviewRepo)
    {
        $this->trainerReviewRepository = $trainerReviewRepo;
    }

    /**
     * Display a listing of the TrainerReview.
     * GET|HEAD /trainerReviews
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function index(Request $request)
    {
        $trainerReviews = $this->trainerReviewRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        );


        if (auth('sanctum')->check() && $request->user()?->role =='trainer') {
            $trainerReviews = $trainerReviews->where('trainer_id', auth('sanctum')->id());
        }

        if ($request->get('trainer_id')){
            $trainerReviews = $trainerReviews->where('trainer_id',$request->trainer_id);
        }

       // $trainerReviews = $trainerReviews->sortBy('created_at','desc');


//        if($request->user()->role =='trainer'){
//            $trainerReviews = $trainerReviews->where('trainer_id',auth()->id());
//        }
//
//        if($request->user()->role =='student'){
//            $trainerReviews = $trainerReviews->where('student_id',auth()->id());
//        }

        return $this->sendResponse(
            TrainerReviewResource::collection($trainerReviews),
            __('messages.retrieved', ['model' => __('models/trainerReviews.plural')])
        );
    }

    /**
     * Store a newly created TrainerReview in storage.
     * POST /trainerReviews
     *
     * @param CreateTrainerReviewAPIRequest $request
     *
     * @return \Illuminate\Http\JsonResponse
     */
    public function store(CreateTrainerReviewAPIRequest $request)
    {
        $input = $request->all();

        $input['student_id'] = auth('sanctum')->id();

        $trainerReview = $this->trainerReviewRepository->create($input);

        return $this->sendResponse(
            new TrainerReviewResource($trainerReview),
            __('messages.saved', ['model' => __('models/trainerReviews.singular')])
        );
    }

    /**
     * Display the specified TrainerReview.
     * GET|HEAD /trainerReviews/{id}
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        /** @var TrainerReview $trainerReview */
        $trainerReview = $this->trainerReviewRepository->find($id);

        if (empty($trainerReview)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/trainerReviews.singular')])
            );
        }

        return $this->sendResponse(
            new TrainerReviewResource($trainerReview),
            __('messages.retrieved', ['model' => __('models/trainerReviews.singular')])
        );
    }

    /**
     * Update the specified TrainerReview in storage.
     * PUT/PATCH /trainerReviews/{id}
     *
     * @param int $id
     * @param UpdateTrainerReviewAPIRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateTrainerReviewAPIRequest $request)
    {
        $input = $request->all();

        /** @var TrainerReview $trainerReview */
        $trainerReview = $this->trainerReviewRepository->find($id);

        if (empty($trainerReview)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/trainerReviews.singular')])
            );
        }

        $trainerReview = $this->trainerReviewRepository->update($input, $id);

        return $this->sendResponse(
            new TrainerReviewResource($trainerReview),
            __('messages.updated', ['model' => __('models/trainerReviews.singular')])
        );
    }

    /**
     * Remove the specified TrainerReview from storage.
     * DELETE /trainerReviews/{id}
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        /** @var TrainerReview $trainerReview */
        $trainerReview = $this->trainerReviewRepository->find($id);

        if (empty($trainerReview)) {
            return $this->sendError(
                __('messages.not_found', ['model' => __('models/trainerReviews.singular')])
            );
        }

        $trainerReview->delete();

        return $this->sendResponse(
            $id,
            __('messages.deleted', ['model' => __('models/trainerReviews.singular')])
        );
    }
}
