<?php

namespace App\Http\Resources;

use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Storage;

class TrainerResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        return [
            'id' => $this->id,
            'name' => $this->name,
            'country_code' => $this->country_code,
            'phone' => $this->phone,
            'business_phone' => $this->business_phone,
            'email' => $this->email,
            'gender' => trans('enum.'.$this->gender),
            'country_id' => $this->country_id,
            'city_id' => $this->city_id,
            'region_id' => $this->region_id,
            'active' => $this->active,
            'online'  => (bool)$this->online,
            'special_trainer'  => (bool)$this->special_trainer,
            'review_avg_rate' => round($this->reviews->avg('rate')),
            'review_counts' => $this->reviews->count(),
            'lat' => $this->lat,
            'lng' => $this->lng,
            'distance' =>  $this->lat?number_format((float)round(vincentyGreatCircleDistance(auth()->user()->lat,auth()->user()->lng,$this->lat,$this->lng),2), 2, '.', ''):null,
            'logo' => $this->logo <> null ? url(Storage::url($this->logo)):"",
            'subscription' => $this->subscription? new SubscriptionResource($this->subscription):null,
            'trainer_regions' => TrainerRegionsResource::collection($this->trainer_regions),
            'created_at' => $this->created_at->timezone('Africa/Cairo')->format('Y-m-d H:i:s'),
            'updated_at' => $this->updated_at->timezone('Africa/Cairo')->format('Y-m-d H:i:s')
        ];
    }
}
