<?php

namespace App\Http\Resources\admin;

use App\Http\Resources\AgeCategoryResource;
use App\Http\Resources\ChampionshipWinnersSubscriberResource;
use App\Http\Resources\CityResource;
use App\Http\Resources\CountryResource;
use App\Http\Resources\RegionResource;
use App\Http\Resources\SubscriptionResource;
use App\Http\Resources\TypeLevelResource;
use App\Models\AgeCategory;
use App\Models\Championship;
use App\Models\Competition;
use App\Models\TrainerMessage;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Storage;

class StudentResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        return [
            'id' => $this->id,
            'name' => $this->name,
            'phone' => $this->phone,
            'birth_date' => $this->birth_date,
            'gender' => trans('enum.'.$this->gender),
            'country' => new CountryResource($this->country),
            'city' =>  new CityResource($this->city),
            'region' =>  new RegionResource($this->region),
            'active' => $this->active,
            'subscription' => new SubscriptionResource($this->subscription),
            'created_at' => $this->created_at->timezone('Africa/Cairo')->format('Y-m-d H:i:s'),
            'updated_at' => $this->updated_at->timezone('Africa/Cairo')->format('Y-m-d H:i:s'),
            'register_method' => $this->provide_name?? trans('enum.app'),
            'trainings_count' => $this->trainings()->count(),
            'competitions_count' => Competition::where('user_id',$this->id)->orWhereHas('subscribers', fn ($query) => $query->where('user_id', $this->id))->count(),
            'championships_count' => Championship::whereHas('subscribers', fn ($query) => $query->where('user_id', $this->id))->count(),
            'student_level'  => $this->student_level ?? 0,
            'online'  => (bool)$this->online,
            'student_points'  => $this->student_points??0,
            'trainers_count' => TrainerMessage::where('student_id',$this->id)->pluck('trainer_id')->count(),
            'logo' => $this->logo <> null ? url(Storage::url($this->logo)):"",
            'last_championship' => new ChampionshipWinnersSubscriberResource($this->winners_subscribers()?->first()) ,
            'last_championship_order' => $this->winners_subscribers()?->first()?->order ,
            'age_category' => $this->age_category_title,
            'levels'  =>  TypeLevelResource::collection($this->levels),
        ];
    }
}
