<?php

namespace App\Http\Resources\admin;

use App\Http\Resources\CityResource;
use App\Http\Resources\CountryResource;
use App\Http\Resources\RegionResource;
use App\Http\Resources\SubscriptionResource;
use App\Http\Resources\TrainerReviewResource;
use App\Models\Competition;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Storage;

class TrainerResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        return [
            'id' => $this->id,
            'name' => $this->name,
            'phone' => $this->phone,
            'business_phone' => $this->business_phone,
            'review_avg_rate' => round($this->reviews->avg('rate')),
            'email' => $this->email,
            'gender' => trans('enum.'.$this->gender),
            'country' => new CountryResource($this->country),
            'city' =>  new CityResource($this->city),
            'region' =>  new RegionResource($this->region),

            'subscription' => new SubscriptionResource($this->subscription),
            'register_method' => $this->provide_name?? trans('enum.app'),

            'trainings_count' => $this->trainings()->count(),
            'competitions_count' => Competition::where('user_id',$this->id)->count(),

            'active' => $this->active,
            'online'  => (bool)$this->online,
            'special_trainer'  => (bool)$this->special_trainer,

            'review_counts' => $this->reviews->count(),
            'logo' => $this->logo <> null ? url(Storage::url($this->logo)):"",

            'created_at' => $this->created_at->timezone('Africa/Cairo')->format('Y-m-d H:i:s'),
            'updated_at' => $this->updated_at->timezone('Africa/Cairo')->format('Y-m-d H:i:s')
        ];
    }
}
