<?php

use Intervention\Image\Drivers\Gd\Driver;
use Intervention\Image\ImageManager;
use Google\Auth\Credentials\ServiceAccountCredentials;
use GuzzleHttp\Client;


function transliterateArabicToEnglish($text) {
    $transliterator = Transliterator::create('Any-Latin; Latin-ASCII');
    return $transliterator->transliterate($text);
}


function formatPhoneNumber($phoneNumber)
{
    $phoneNumber = preg_replace('/\D/', '', $phoneNumber);

    if (substr($phoneNumber, 0, 1) === '0') {
        $phoneNumber = '+20' . substr($phoneNumber, 1);
    }

    return $phoneNumber;
}

function CertificateEng($student_name, $championship_title, $championship_date): string
{
    $manager = new ImageManager(new Driver());

    // read image from file system
    $image = $manager->read(public_path('certificates_blade/Certificate-Eng.png'));

    $image->text(preg_match('/\p{Arabic}/u', $student_name) ?transliterateArabicToEnglish($student_name):$student_name, 170, 145, function($font) {
        $font->file(public_path('fonts/Cairo-SemiBold.ttf'));
        $font->size(18);
        $font->color('#ff7300');
        $font->align('center');
        $font->valign('bottom');
        $font->angle(0);
    });


    $image->text(preg_match('/\p{Arabic}/u', $championship_title) ?transliterateArabicToEnglish($championship_title):$championship_title, 170, 68, function($font) {
        $font->file(public_path('fonts/Cairo-SemiBold.ttf'));
        $font->size(10);
        $font->color('#607685');
        $font->align('center');
        $font->valign('bottom');
        $font->angle(0);
    });


    $image->text(now()->format('d/m/Y'), 265, 230, function($font) {
        $font->file(public_path('fonts/Cairo-SemiBold.ttf'));
        $font->size(10);
        $font->color('#000000');
        $font->align('center');
        $font->valign('bottom');
        $font->angle(0);
    });

    $image->text($championship_date->format('d F Y'), 296, 165, function($font) {
        $font->file(public_path('fonts/Cairo-SemiBold.ttf'));
        $font->size(9);
        $font->color('#203f54');
        $font->align('center');
        $font->valign('bottom');
        $font->angle(0);
    });

    // insert watermark
    //$image->place('images/watermark.png');

    // save modified image in new format
    $certificate_title = 'certificates/'.$student_name.'-eng'.$championship_title.uniqid().'.png';
     $image->save(public_path($certificate_title));

     return $certificate_title;
}

function utf8_strrev($str){
    preg_match_all('/./us', $str, $ar);
    return join(array_reverse($ar[0]));
}

function mb_strrev($str){
    $r = '';
    for ($i = mb_strlen($str); $i>=0; $i--) {
        $r .= mb_substr($str, $i, 1);
    }
    return $r;
}

function CertificateAr($student_name, $championship_title, $championship_date): string
{
    $manager = new ImageManager(new Driver());

    // read image from file system
    $image = $manager->read(public_path('certificates_blade/Certificate-Ar.png'));


    $image->text(preg_match('/\p{Arabic}/u', $student_name) ?transliterateArabicToEnglish($student_name):$student_name, 170, 145, function($font) {
        $font->file(public_path('fonts/Cairo-SemiBold.ttf'));
        $font->size(18);
        $font->color('#ff7300');
        $font->align('center');
        $font->valign('bottom');
        $font->angle(0);
    });


    $image->text(preg_match('/\p{Arabic}/u', $championship_title) ?transliterateArabicToEnglish($championship_title):$championship_title, 170, 68, function($font) {
        $font->file(public_path('fonts/Cairo-SemiBold.ttf'));
        $font->size(10);
        $font->color('#607685');
        $font->align('center');
        $font->valign('bottom');
        $font->angle(0);
    });


    $image->text(now()->format('d/m/Y'), 265, 230, function($font) {
        $font->file(public_path('fonts/Cairo-SemiBold.ttf'));
        $font->size(10);
        $font->color('#000000');
        $font->align('center');
        $font->valign('bottom');
        $font->angle(0);
    });

    $image->text($championship_date->format('d F Y'), 90, 165, function($font) {
        $font->file(public_path('fonts/Cairo-SemiBold.ttf'));
        $font->size(9);
        $font->color('#203f54');
        $font->align('center');
        $font->valign('bottom');
        $font->angle(0);
    });

    // insert watermark
    //$image->place('images/watermark.png');

    // save modified image in new format
    $certificate_title = 'certificates/'.$student_name.'-ar'.$championship_title.uniqid().'.png';
     $image->save(public_path($certificate_title));

     return $certificate_title;
}

function exam_equation($a, $b, $c): float|int
{
$d = $b / $c ;
$e = $a - $b ;
$f = $e / $d ;
$g = $c + $f ;
return $g ;
}

function vincentyGreatCircleDistance($latitudeFrom, $longitudeFrom, $latitudeTo, $longitudeTo, $earthRadius = 6371): float|int
{

    if (($latitudeFrom == $latitudeTo) && ($longitudeFrom == $longitudeTo)) {
        return 0;
    }

    // convert from degrees to radians
    $latFrom = deg2rad($latitudeFrom);
    $lonFrom = deg2rad($longitudeFrom);
    $latTo = deg2rad($latitudeTo);
    $lonTo = deg2rad($longitudeTo);

    $lonDelta = $lonTo - $lonFrom;
    $a = pow(cos($latTo) * sin($lonDelta), 2) +
        pow(cos($latFrom) * sin($latTo) - sin($latFrom) * cos($latTo) * cos($lonDelta), 2);
    $b = sin($latFrom) * sin($latTo) + cos($latFrom) * cos($latTo) * cos($lonDelta);

    $angle = atan2(sqrt($a), $b);

    return $angle * $earthRadius;
}



function sendFirebaseNotification($token, $title, $message)
{
    $credentialsPath = public_path('drmath-aa8e8-firebase-adminsdk-fgewn-681406ac7e.json'); // تأكد من أن المسار صحيح
    $credentials = new \Google\Auth\Credentials\ServiceAccountCredentials(
        'https://www.googleapis.com/auth/firebase.messaging',
        $credentialsPath
    );

    // احصل على التوكن
    $accessToken = $credentials->fetchAuthToken()['access_token'];

    // تأكد من أن $message هو نص وليس كائنًا
    $body = is_string($message) ? $message : json_encode($message);

    // بنية الإشعار
    $notification = [
        'message' => [
            'token' => $token,
            'notification' => [
                'title' => $title,
                'body' => $body, // استخدم النص هنا
            ],
            'android' => [
                'priority' => 'high',
            ],
            'apns' => [
                'headers' => [
                    'apns-priority' => '10',
                ],
                'payload' => [
                    'aps' => [
                        'sound' => 'default',
                    ],
                ],
            ],
        ],
    ];

    $url = 'https://fcm.googleapis.com/v1/projects/drmath-aa8e8/messages:send';

    $client = new \GuzzleHttp\Client();

    try {
        $response = $client->post($url, [
            'headers' => [
                'Authorization' => 'Bearer ' . $accessToken,
                'Content-Type' => 'application/json',
            ],
            'json' => $notification,
        ]);

        return json_decode($response->getBody()->getContents(), true);
    } catch (\Exception $e) {
        error_log('FCM Send Exception: ' . $e->getMessage());
        return [
            'error' => $e->getMessage(),
        ];
    }
}
