<?php

namespace App\Models;

use Eloquent as Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
// use Spatie\Translatable\HasTranslations;

/**
 * Class Championship
 * @package App\Models
 * @version April 16, 2024, 8:02 am UTC
 *
 * @property string $title
 * @property boolean $active
 * @property boolean $finish
 * @property string $start_at
 */
class Championship extends Model
{
    use SoftDeletes;

//    use HasTranslations;
//    public $translatable = ['title','slogan'];

    public $table = 'championships';


    protected $dates = ['deleted_at'];


    // protected $appends = ['end_time'];

    // public function getEndTimeAttribute(){
    //     return $this->start_at ? $this->start_at->addMinutes($this->training_period) : null;
    // }


    public $fillable = [
        'title',
        'slogan',
        'slogan',
        'type',
        'price',
        'active',
        'finish',
        'training_period',
        'answer_type',
        'question_type_id',
        'language',
        'start_at',
        'expired_at'
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'title' => 'string',
        'active' => 'boolean',
        'finish' => 'boolean',
        'start_at' => 'datetime',
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        'title' => 'required',
        'start_at' => 'required'
    ];

    public function subscribers(){
        return $this->hasMany(ChampionshipSubscriber::class)->orderByDesc('supposed_solved')->orderBy('student_points','desc');
    }

    public function my_subscriber(){
        return $this->hasOne(ChampionshipSubscriber::class)->where('user_id',auth('sanctum')->id());
    }

//    public function type_level(): BelongsTo
//    {
//        return $this->belongsTo(TypeLevel::class);
//    }
//
//    public function level_category(): BelongsTo
//    {
//        return $this->belongsTo(LevelCategory::class);
//    }
//
//    public function question_type(): BelongsTo
//    {
//        return $this->belongsTo(QuestionType::class);
//    }
//
//    public function age_category(): BelongsTo
//    {
//        return $this->belongsTo(AgeCategory::class);
//    }

    public function levels(): BelongsToMany
    {
        return $this->belongsToMany(TypeLevel::class, 'championship_levels');
    }

    public function championship_levels(): HasMany
    {
        return $this->hasMany(ChampionshipLevel::class);
    }

    public function winners_subscribers(){
        return $this->hasMany(ChampionshipSubscriber::class)->whereNotNull('order')->orderBy('order','asc')->orderByDesc('supposed_solved')->orderBy('student_points','desc');
    }

    public function scopeMustFinished($query)
    {
           return $query->where('start_at','<' ,now()->subMinutes($this->training_period)->timezone('Africa/Cairo'))->where('finish',0);
    }


}
