<?php

namespace App\Models;

use Eloquent as Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

/**
 * Class ChampionshipSubscriber
 * @package App\Models
 * @version April 16, 2024, 8:03 am UTC
 *
 * @property integer $championship_id
 * @property integer $user_id
 * @property integer $correct_answers_count
 * @property integer $wrong_answers_count
 * @property string $answering_period
 * @property integer $student_points
 * @property boolean $active
 * @property boolean $finish
 * @property boolean $student_points_is_collected
 */
class ChampionshipSubscriber extends Model
{
    use SoftDeletes;

    use HasFactory;

    public $table = 'championship_subscribers';


    protected $dates = ['deleted_at'];



    public $fillable = [
        'championship_id',
        'type_level_id',
        'age_category_id',
        'user_id',
        'correct_answers_count',
        'wrong_answers_count',
        'answering_period',
        'remaining_time',
        'student_points',
        'supposed_solved',
        'active',
        'finish',
        'student_points_is_collected'
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'championship_id' => 'integer',
        'user_id' => 'integer',
        'correct_answers_count' => 'integer',
        'wrong_answers_count' => 'integer',
        'answering_period' => 'string',
        'student_points' => 'integer',
        'active' => 'boolean',
        'finish' => 'boolean',
        'student_points_is_collected' => 'boolean'
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        'championship_id' => 'required|exists:championships,id',
        'correct_answers_count' => 'numeric',
        'wrong_answers_count' => 'numeric',
        'student_points' => 'numeric'
    ];

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function championship()
    {
        return $this->belongsTo(Championship::class);
    }

    public function age_category()
    {
        return $this->belongsTo(AgeCategory::class);
    }

    public function type_level()
    {
        return $this->belongsTo(TypeLevel::class,'type_level_id');
    }


}
