<?php

namespace App\Models;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Eloquent as Model;
use Illuminate\Database\Eloquent\SoftDeletes;

use Spatie\Translatable\HasTranslations;

/**
 * Class City
 * @package App\Models
 * @version March 23, 2024, 12:47 pm UTC
 *
 * @property string $name
 * @property integer $country_id
 */
class City extends Model
{
    use SoftDeletes;


    use HasTranslations;

    public $translatable = ['name'];

    public $table = 'cities';


    protected $dates = ['deleted_at'];

    public $fillable = [
        'name',
        'country_id'
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'name' => 'string',
        'country_id' => 'integer'
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        'name' => 'required',
        'country_id' => 'required|exists:countries,id'
    ];

    public function country()
    {
        return $this->belongsTo(Country::class,'country_id');
    }

    public function regions(): HasMany
    {
        return $this->hasMany(Region::class);
    }


}
