<?php

namespace App\Models;

use App\Models\Models\CompetitionQuestion;
use App\Models\Models\SubscriberCompetitionQuestionAnswer;
use Eloquent as Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

/**
 * Class CompetitionSubscriber
 * @package App\Models
 * @version April 5, 2024, 11:01 pm UTC
 *
 * @property integer $competition_id
 * @property integer $user_id
 * @property integer $correct_answers_count
 * @property integer $wrong_answers_count
 * @property string $answering_period
 * @property integer $student_points
 * @property boolean $active
 * @property boolean $finish
 * @property boolean $student_points_is_collected
 */
class CompetitionSubscriber extends Model
{
    use SoftDeletes;

    use HasFactory;

    public $table = 'competition_subscribers';


    protected $dates = ['deleted_at'];



    public $fillable = [
        'competition_id',
        'user_id',
        'correct_answers_count',
        'wrong_answers_count',
        'answering_period',
        'remaining_time',
        'student_points',
        'supposed_solved',
        'active',
        'finish',
        'student_points_is_collected'
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'competition_id' => 'integer',
        'user_id' => 'integer',
        'correct_answers_count' => 'integer',
        'wrong_answers_count' => 'integer',
        'answering_period' => 'string',
        'student_points' => 'integer',
        'active' => 'boolean',
        'finish' => 'boolean',
        'student_points_is_collected' => 'boolean'
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        'competition_id' => 'required|exists:competitions,id',
        'correct_answers_count' => 'numeric',
        'wrong_answers_count' => 'numeric',
        'student_points' => 'numeric'
    ];

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function competition()
    {
        return $this->belongsTo(Competition::class);
    }


    public function answers(): HasMany
    {
        return $this->hasMany(SubscriberCompetitionQuestionAnswer::class,'competition_subscriber_id');
    }

}
