<?php

namespace App\Models;

use Eloquent as Model;
use Illuminate\Database\Eloquent\SoftDeletes;

use Spatie\Translatable\HasTranslations;

/**
 * Class LevelCategory
 * @package App\Models
 * @version March 23, 2024, 12:52 pm UTC
 *
 * @property string $title
 * @property integer $type_level_id
 */
class LevelCategory extends Model
{
    use SoftDeletes;


    use HasTranslations;
    public $translatable = ['title'];

    public $table = 'level_categories';


    protected $dates = ['deleted_at'];



    public $fillable = [
        'title',
        'icon',
        'active',
        'type_level_id'
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'title' => 'string',
        'type_level_id' => 'integer'
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        'title' => 'required',
        'type_level_id' => 'required|exists:type_levels,id'
    ];

    public static $update_rules = [
        'title' => 'sometimes',
    ];

    public function type_level (){
        return $this->belongsto(TypeLevel::class);
    }

    public function questions (){
        return $this->hasMany(Question::class);
    }


}
