<?php

namespace App\Models;

use Eloquent as Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

/**
 * Class Question
 * @package App\Models
 * @version March 28, 2024, 10:09 pm UTC
 *
 * @property integer $training_type_id
 * @property integer $type_level_id
 * @property integer $level_category_id
 * @property integer $numbers_count
 * @property integer $answer
// * @property string $choices
// * @property json $numbers
 * @property boolean $active
 */
class Question extends Model
{
    use SoftDeletes;

    use HasFactory;

    public $table = 'questions';


    protected $dates = ['deleted_at'];



    public $fillable = [
        'training_type_id',
        'type_level_id',
        'level_category_id',
        'numbers_count',
        'answer',
        'choices',
        'numbers',
        'active',
        'number1',
        'number2',
        'number3',
        'number4',
        'number5',
        'number6',
        'number7',
        'number8',
        'number9',
        'number10',
        'choice1',
        'choice2',
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'training_type_id' => 'integer',
        'type_level_id' => 'integer',
        'level_category_id' => 'integer',
        'numbers_count' => 'integer',
        'answer' => 'integer',
        'active' => 'boolean'
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        'training_type_id' => 'exists:training_types,id',
        'type_level_id' => 'exists:type_levels,id',
        'level_category_id' => 'exists:level_categories,id',
         'numbers_count' => 'required|numeric',
        'answer' => 'required|numeric',
//        'choice1' => 'required|numeric',
//        'choice2' => 'required|numeric',
//        'number1' => 'required',
//        'number2' => 'required',
//        'numbers' => 'required',
//        'choices' => 'required'
    ];

    public function training_type(): BelongsTo
    {
        return $this->belongsTo(TrainingType::class);
    }

    public function type_level(): BelongsTo
    {
        return $this->belongsTo(TypeLevel::class);
    }

    public function level_category(): BelongsTo
    {
        return $this->belongsTo(LevelCategory::class);
    }


}
