<?php

namespace App\Models;

use Eloquent as Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

/**
 * Class Subscription
 * @package App\Models
 * @version March 31, 2024, 12:17 am UTC
 *
 * @property integer $package_id
 * @property integer $user_id
 * @property string $start_date
 * @property string $end_date
 * @property boolean $active
 */
class Subscription extends Model
{
    use SoftDeletes;

    use HasFactory;

    public $table = 'subscriptions';


    protected $dates = ['deleted_at','start_date','end_date'];



    public $fillable = [
        'package_id',
        'user_id',
        'coupon_id',
        'cost',
        'start_date',
        'end_date',
        'active'
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'package_id' => 'integer',
        'user_id' => 'integer',
        'active' => 'boolean'
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        'package_id' => 'required|exists:packages,id',
        'user_id' => 'required|exists:users,id',
        'start_date' => 'required',
        'end_date' => 'required'
    ];

    public function package(): BelongsTo
    {
        return $this->belongsTo(Package::class);
    }


}
