<?php

namespace App\Models;

use Eloquent as Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

/**
 * Class TrainerRegion
 * @package App\Models
 * @version April 24, 2024, 7:34 am UTC
 *
 * @property integer $user_id
 * @property integer $country_id
 * @property integer $city_id
 * @property integer $region_id
 * @property string $address
 * @property string $lat
 * @property string $lng
 */
class TrainerRegion extends Model
{
    use SoftDeletes;

    use HasFactory;

    public $table = 'trainer_regions';


    protected $dates = ['deleted_at'];



    public $fillable = [
        'user_id',
        'country_id',
        'city_id',
        'region_id',
        'address',
        'lat',
        'lng'
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'user_id' => 'integer',
        'country_id' => 'integer',
        'city_id' => 'integer',
        'region_id' => 'integer',
        'address' => 'string',
        'lat' => 'string',
        'lng' => 'string'
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        'country_id' => 'required|exists:countries,id',
        'city_id' => 'required|exists:cities,id',
        'region_id' => 'required|exists:regions,id',
        'address' => 'required',
        'lat' => 'required',
        'lng' => 'required'
    ];

    public function region()
    {
        return $this->belongsTo(Region::class,'region_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class,'user_id');
    }

}
