<?php

namespace App\Models;

use Eloquent as Model;
use Illuminate\Database\Eloquent\SoftDeletes;

use Spatie\Translatable\HasTranslations;

/**
 * Class TypeLevel
 * @package App\Models
 * @version March 23, 2024, 12:52 pm UTC
 *
 * @property string $title
 * @property integer $training_type_id
 */
class TypeLevel extends Model
{
    use SoftDeletes;


    use HasTranslations;

    public $translatable = ['title'];

    public $table = 'type_levels';


    protected $dates = ['deleted_at'];



    public $fillable = [
        'title',
        'icon',
        'active',
        'training_type_id'
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'title' => 'string',
        'training_type_id' => 'integer'
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        'title' => 'required',
        'training_type_id' => 'required|exists:training_types,id'
    ];

    public function level_categories (){
        return $this->hasMany(LevelCategory::class);
    }

    public function training_type (){
        return $this->belongsto(TrainingType::class);
    }


}
