<?php

namespace App\Traits;

trait Authorizable {
	private $abilities = [
		'index' => 'view',
		'edit' => 'edit',
		'show' => 'view',
		'update' => 'edit',
		'create' => 'add',
		'store' => 'add',
		'destroy' => 'delete',
	];

	/**
	 * Override of callAction to perform the authorization before
	 *
	 * @param $method
	 * @param $parameters
	 * @return mixed
	 */
	public function callAction($method, $parameters) {

        if (auth('sanctum')->check() && auth('sanctum')->user()->role == "sub_admin" && $ability = $this->getAbility($method)) {
			$this->authorize($ability);
		}

		return parent::callAction($method, $parameters);
	}

	public function getAbility($method) {
		$routeName = explode('.', \Request::route()->getName());
		$action = array_get($this->getAbilities(), $method);

		if (!isset($routeName[0])) {
			return null;
		}
		return $action ? $action . '_' . $routeName[0] : null;
	}

	private function getAbilities() {

		return $this->abilities;
	}

	public function setAbilities($abilities) {
		$this->abilities = $abilities;
	}
}
